; This implements the Julian Day algorithm given in
; Seidelmann 12.92
; regard that the original algorithm calculates the JD for 12h
; INPUTS:  jd DBLARR fractional Julian Day numbers
; OUTPUTS: y,m,d,h,minute,sec  Gregorian Calendar Date
; KEYWORDS: compute 0/1 calculate JD from Date
;           break   0/1 calculate Date from JD [default]
; COMMENT: fractional input/output is in TT not UTC.
; HISTORY: M.Fraenz 2001

 PRO JULIAN_GREG,jd,y,m,d,h,minute,sec,break=break,compute=compute
 
  IF KEYWORD_SET(compute) THEN BEGIN
   yvar=LONG(y)+4800l+(LONG(m)-14l)/12l
   jd=(yvar*1461l)/4l
   jd=jd+((LONG(m)-2l-((LONG(m)-14l)/12l)*12l)*367l)/12l
   yvar=yvar+100l
   jd=DOUBLE(jd-((yvar/100l)*3l)/4l+LONG(d)-32076l)+0.5d ; for 0h!
   IF N_ELEMENTS(h) GT 0 THEN jd=jd+double(h)/24.0d
   IF N_ELEMENTS(minute) GT 0 THEN jd=jd+double(minute)/24.0d/60.0d
   IF N_ELEMENTS(sec) GT 0 THEN jd=jd+double(sec)/24.0d/3600.0d
 ENDIF ELSE BEGIN
   ljd=LONG(jd)
   fjd=jd-ljd
   index=WHERE(fjd GE 0.5d)
   lindex=WHERE(fjd LT 0.5d)
   IF index(0) NE -1 THEN BEGIN
    ljd(index)=ljd(index)+1l
    fjd(index)=fjd(index)-0.5d
   ENDIF
   IF lindex(0) NE -1 THEN BEGIN
    fjd(lindex)=fjd(lindex)+0.5d
   ENDIF
   L=ljd+68569l
   N=(L*4l)/146097l
   L=L-(146097l*N+3l)/4l
   I=((L+1l)*4000l)/1461100l
   L=L-((I*1461l)/4l)+31l
   J=(L*80l)/2447l
   d=LONG(L-(J*2447l)/80l)
   L=J/11l
   m=LONG(J+2-L*12l)
   y=LONG(I+L+(N-49l)*100l)
   h=LONG(fjd*24d)
   minute=LONG(fjd*1440d)-h*60l
   sec=LONG(fjd*86400d)-h*3600l-minute*60l
 ENDELSE
 
 RETURN
 END
