; Plot ephemerical data from DE200 and VSOP87 for a fixed
; number of times starting at a specified Julian date

 PRO PLOTEPH,ipla,jdoff,j2000=j2000,jorder=jorder,dev=dev,encaps=encaps, $
    vorder=vorder,aorder=aorder,velocity=velocity

;     ipla      planet index (integer).
;               ipla=1 Mercury                  ipla=5 Jupiter
;               ipla=2 Venus                    ipla=6 Saturn
;               ipla=3 Earth-Moon Barycenter    ipla=7 Uranus
;               ipla=4 Mars                     ipla=8 Neptune
;               ipla=10 Moon                    ipla=11 Sun
;               ipla=12 Earth
;
;    jdoff      DOUBLE start distance in days from J2000.0
;               set stepsize and counts below
;   KEYWORDS:
;    j2000   0/1 use J2000.0 equator
;   jorder   1-4   order of ecl. of date DE200 correction
;   aorder   -1-3   order of aberration correction
;   vorder   -4-6   order of VSOP87 comparison
;   velocity 0/1 compare VSOP87 and DE200 velocity vectors

 IF NOT KEYWORD_SET(dev) THEN dev='X' ELSE dev=STRUPCASE(dev)
 encaps=KEYWORD_SET(encaps)
  IF NOT KEYWORD_SET(vorder) THEN vorder=3

 
 j2000=KEYWORD_SET(j2000)
 jorderset=KEYWORD_SET(jorder)
 aorderset=KEYWORD_SET(aorder)
 velocityset=KEYWORD_SET(velocity)
 jd2000=2451545.0d
 startjd=jd2000+jdoff
 stepsize=50 ; Days
 counts=800l     ;
 jdarr=DINDGEN(counts)*stepsize+startjd
 tj=(jdarr-jd2000)/36525.0d
 targetstr=['Mercury','Venus','EMB','Mars','Jupiter','Saturn','Uranus','Neptune', $
            'Pluto','Moon','Sun','Earth']


; Get DE200 values
 target=ipla
 au=1.4959787d8
 msec=au/86.4d
 dtor=!dpi/180.0d
 ecliptic=(jorderset EQ 0b) AND (aorderset EQ 0b)

 eph=TRUEJPL(tj,target,center=11+aorderset,eclip=ecliptic,nonut=(ecliptic EQ 1b),noprec=j2000,order=3,aberr=3*aorderset)
 IF counts GT 1 THEN depos=TRANSPOSE(eph.pos) ELSE depos=eph.pos
 IF counts GT 1 THEN devel=TRANSPOSE(eph.vel) ELSE devel=eph.vel
 delon=TRANSPOSE(eph.lon)
 delat=TRANSPOSE(eph.lat)
 der=TRANSPOSE(eph.r)
 
;     print,'LON:',STRING(MINSEC(delon(0),/r),f='(g20.9)')
;     print,'LAT:',STRING(MINSEC(!dpi/2-delat(0),/r,/decl),f='(g20.9)')
;     print,'r:',STRING(der(0),f='(g20.7)')
 
 
 IF jorderset THEN BEGIN
  IF jorder EQ 1 THEN outorder=1 ELSE outorder=3
  eph1=TRUEJPL(tj,target,center=11,nonut=(jorder MOD 2) EQ 0,noprec=(jorder GE 3),order=outorder)
  IF counts GT 1 THEN vpos=TRANSPOSE(eph1.pos) ELSE vpos=eph1.pos
  IF counts GT 1 THEN vvel=TRANSPOSE(eph1.vel) ELSE vvel=eph1.vel
  vlon=TRANSPOSE(eph1.lon)
  vlat=TRANSPOSE(eph1.lat)
  rvec=TRANSPOSE(eph1.r)
 !p.title='DE200 for '+targetstr(ipla-1)
 IF j2000 THEN !p.title=!p.title+' (J2000.0)' $
  ELSE !p.title=!p.title+' (Date)'
 CASE jorder OF
  1:!p.title=!p.title+',1st-3rd PrecNut'
  2:!p.title=!p.title+',NoNut'
  3:!p.title=!p.title+',NoPrec'
  4:!p.title=!p.title+',NoNutNoPrec'
 ENDCASE
 
 ENDIF ELSE IF aorderset THEN BEGIN
  IF aorder EQ -1 THEN aorderout=0b ELSE aorderout=aorder
  eph1=TRUEJPL(tj,target,center=12,nonut=0b,noprec=0b,aberr=aorderout,order=3)
  IF counts GT 1 THEN vpos=TRANSPOSE(eph1.pos) ELSE vpos=eph1.pos
  IF counts GT 1 THEN vvel=TRANSPOSE(eph1.vel) ELSE vvel=eph1.vel
  vlon=TRANSPOSE(eph1.lon)
  vlat=TRANSPOSE(eph1.lat)
  rvec=TRANSPOSE(eph1.r)
  !p.title='DE200 for '+targetstr(ipla-1)
  IF j2000 THEN !p.title=!p.title+' (J2000.0)' $
   ELSE !p.title=!p.title+' (Date)'
  CASE aorder OF
  -1:!p.title=!p.title+',No Aberration-Aberration'
  1:!p.title=!p.title+', No Lighttime, No deflec.'
  2:!p.title=!p.title+',No rel. deflection'
  3:!p.title=!p.title+'Test'
  ENDCASE
 
 ENDIF  ELSE BEGIN
 
; Get VSOP87 values

  IF vorder EQ 5 THEN ipla=3
  PLANETAP,jdarr,ipla,vlon,vlat,rvec,vpos,vvel,ierr,date=(j2000 EQ 0)*1,order=vorder

 ;PRINT,MINSEC(TRANSPOSE(delon/dtor)),MINSEC(90-TRANSPOSE(delat/dtor),/dec)
 ;PRINT,devel*kmsec
 ;PRINT,MINSEC(vlon/dtor),MINSEC(90-vlat/dtor,/dec)
 ;PRINT,vvel*kmsec
  !p.title='VSOP-DE200 for '+targetstr(ipla-1)
 IF j2000 THEN !p.title=!p.title+' (J2000.0)' $
  ELSE !p.title=!p.title+' (Date)'
 CASE vorder OF
  -4:!p.title=!p.title+',1st approx'
  -3:!p.title=!p.title+',1st Dist paper'
  -2:!p.title=!p.title+',1st paper'
  -1:!p.title=!p.title+',1st+Dist.'
  1:!p.title=!p.title+',1st'
  2:!p.title=!p.title+',1st+2nd'
  3:!p.title=!p.title+',1st+2nd+Dist'
  4:!p.title=!p.title+',mean'
  5:!p.title=!p.title+',EMB-Earth'
  6:!p.title=!p.title+',EMB-Earth pap'
 ENDCASE
 
 ENDELSE
 
 IF velocityset THEN BEGIN
 
  veldif=(vvel-devel)*msec
  latdif=veldif(*,0)
  londif=veldif(*,1)
  rdif=veldif(*,2)
  vdif=SQRT(TOTAL(veldif*veldif,2))
  maxv=FLOAT(max(abs(vdif)))

 
  !p.title=!p.title+',Velocity'
  filehead='vl'
  ytitlat= 'Vxdif [m/s]'
  ytitlon= 'Vydif [m/s]'
  ytitr=   'Vzdif [m/s]'
  ytitv=   'Vdif [m/s]'
  panelnum=4
 ENDIF ELSE BEGIN
 
  posdif=vpos-depos
  posrel=TOTAL(posdif*posdif,2)/TOTAL(depos*depos,2)/dtor*3600.0
  posang=VPHTHR(posdif)
; PRINT,'posdif[km]:'
; PRINT,posdif
; PRINT,'veldif[km/s]:'
; PRINT,veldif
  londif=(vlon-delon)/dtor
  index=WHERE(londif GT 180.0d)
  IF index(0) NE -1 THEN londif(index)=londif(index)-360.0d
  index=WHERE(londif LT -180.0d)
  IF index(0) NE -1 THEN londif(index)=londif(index)+360.0d
  londif=londif*3600
  latdif=(vlat-delat)/dtor*3600
  rdif=(rvec-der)*au

  filehead='pl'
  ytitlat= 'Latdif [arcsec]'
  ytitlon= 'Londif [arcsec]'
  ytitr= 'Rdif [km]'
  panelnum=3
  
 ENDELSE

 maxlon=FLOAT(max(abs(londif)))
 maxlat=FLOAT(max(abs(latdif)))
 maxr=FLOAT(max(abs(rdif)))

 SET_PLOT,dev

 IF encaps THEN extension='.eps' ELSE extension='.ps'
 IF dev EQ 'PS' THEN BEGIN
   DEVICE,xsize=20,ysize=27,fil=filehead+targetstr(ipla-1)+extension,encaps=encaps
 ENDIF
 LOADCT,0
 !p.background=255
 !p.color=0
 !p.charsize=2.0
 !p.thick=1.0
 !p.charthick=1.0
 
 erase
 !p.multi=[panelnum,0,panelnum,0,0]
  
 PLOT,tj*100,latdif,xtit='Years from JD2000',ytit=ytitlat+'!CMax:'+STRTRIM(maxlat,2)
 !p.title=''
 PLOT,tj*100,londif,xtit='Years from JD2000',ytit=ytitlon+'!CMax:'+STRTRIM(maxlon,2)
 PLOT,tj*100,rdif,xtit='Years from JD2000',ytit=ytitr+'!CMax:'+STRTRIM(maxr,2)
 print,'maxlon:',maxlon
 print,'maxlat:',maxlat
 print,'maxr:',maxr
 
 IF velocityset THEN BEGIN
   PLOT,tj*100,vdif,xtit='Years from JD2000',ytit=ytitv+'!CMax:'+STRTRIM(maxv,2)
   print,'maxv:',maxv
 ENDIF
 IF dev EQ 'PS' THEN device,/close
 
 RETURN
 END
