;+**********************************************************************
; SCCS id: %W% %U% %G% 
;***********************************************************************
; PROJECT:   Magnetic holes
;
; COMPONENT: Low B
;
; LANGUAGE:  IDL
;
; NAME: VECPRD
;
; PURPOSE:
;	Calculates the cross product of two arrays of vectors or of 
;	row vectors.
;	
; CATEGORY: general math
;
; CALLING SEQUENCE: Result = VECPRD(v1,v2)
;
; INPUTS:
;	v1,v2:	Arrays of vectors
;	The second index counts the vector coordinates.
;	OR: v1 and v2 are 'row vectors'.
;
; OUTPUTS:
;	Result:	Array of the column vector products.
;
; RESTRICTIONS:
;	If v1 and v2 do not have the same size, the result may be weird.
;
; MODIFICATION HISTORY:
; 	Written by:M.Fraenz 1992
;
;-
  FUNCTION VECPRD,v1,v2
   s1=size(v1)
   IF (s1(0) EQ 1) OR (s1(1) EQ 1) THEN BEGIN
    v3=dblarr(3)
    v3(0)=v1(1)*v2(2)-v1(2)*v2(1)
    v3(1)=v1(2)*v2(0)-v1(0)*v2(2)
    v3(2)=v1(0)*v2(1)-v1(1)*v2(0)
    v3=TRANSPOSE(v3)
   ENDIF ELSE BEGIN
    v3=dblarr(s1(1),3)
    index=INDGEN(s1(1))
    v3(index)=v1(*,1)*v2(*,2)-v1(*,2)*v2(*,1)
    v3(index+s1(1))=v1(*,2)*v2(*,0)-v1(*,0)*v2(*,2)
    v3(index+2*s1(1))=v1(*,0)*v2(*,1)-v1(*,1)*v2(*,0)
   ENDELSE
  return,v3
  end
