;+
; NAME:
;	VPHTHR
;
; PURPOSE:
;	Transform an array of vectors given in Cartesian coordinates
;	into polar coordinates.
;	
; CATEGORY:
;	Coordinate transformation
;
; CALLING SEQUENCE:
;
;	Result = VPHTHR (v [, i])
;
; INPUTS:
;	v: Array (n,3) of vectors in Cartesian coordinates.
;		The second index is the vector component,whereas
;		the first index counts the vectors.
;
; OPTIONAL INPUTS:
;	i: INTARR	If specified, only the i-th components(ph,th,r)
;			are returned.
;			(else: all components)
;                 	
; OUTPUTS:
;	Result: Array (n,3) of vectors in polar coordinates (ph,th,r).
;
; PROCEDURE:
;
; MODIFICATION HISTORY:
; 	Written by: Markus Fraenz MPAE 1992
;
;-
FUNCTION VPHTHR,v,i
r=SQRT(SCLPRD(v,v))
c=N_ELEMENTS(r)
IF c EQ 1 THEN BEGIN
 IF r NE 0.0 THEN ptr=TRANSPOSE([atan(v(1),v(0)),acos(v(2)/r),r]) $
  ELSE ptr = DBLARR(1,3)
 IF N_PARAMS(0) EQ 1 THEN ptrout=ptr ELSE ptrout=ptr(i)
ENDIF ELSE BEGIN
 index = WHERE(r EQ 0.0,c)
 ptr=[[atan(v(*,1),v(*,0))],[acos(v(*,2)/r)],[r]] 
 IF c GT 0 THEN ptr(index,*) = 0.0d0
 IF N_PARAMS(0) EQ 1 THEN ptrout=ptr ELSE ptrout=ptr(*,i)
ENDELSE
return,ptrout
end 
